#include <qvbox.h>
#include <qlabel.h>
#include <qtooltip.h>
#include <qmenubar.h>
#include <qmessagebox.h>
#include <qvaluelist.h>
#include <qpixmap.h>
#include <qstatusbar.h>
#include <qlistview.h>
#include <qfile.h>
#include <qlineedit.h>
#include <qdir.h>
#include <qmenubar.h>
#include <stdlib.h>

#include "mainwindow.h"
#include "mdiwindow.h"
#include "include/resource.h"

MainWindow::MainWindow() :
QMainWindow(0,QString::fromLocal8Bit("MySQL Navigator"),WDestructiveClose)
{
	initialize();
}

MainWindow::~MainWindow()
{
}	

void MainWindow::initialize()
{
	make_layout();

	signal_connect();

	flag = FALSE;

	mysql_init(&mysql);

	needle = NULL;

	slot_windows();

	load_session();

	resize(option.size);

	disable_menu();

	slot_image();
}

void MainWindow::set_base_color(QWidget *widget,QColor color)
{
	QPalette z(widget->palette());

	z.setColor(QColorGroup::Base,color);

	widget->setPalette(z);	
}

void MainWindow::set_image_color(QWidget *widget,QColor color)
{
	QPalette z(widget->palette());

	z.setColor(QColorGroup::Background,color);

	widget->setPalette(z);	
}

QString MainWindow::get_server(QString sql)
{
	for(unsigned int s = 0; s < sql.length(); s++)
	{
		if(sql.at(s) == '@')
		{
			return sql.mid(s + 1);
		}
	}

	return "";
}

void MainWindow::load_history()
{
	char buffer[255];
	int z;

#ifndef WIN32
	sprintf(buffer, "%s/%s", getenv("HOME"), ".mysqlnavigator.history");
#else
	sprintf(buffer, "%s/%s", "c:", ".mysqlnavigator.history");
#endif

	QFile history(buffer);

	if(history.open(IO_ReadOnly) == FALSE)
	{
		return;
	}

	while((z = history.readLine(buffer, sizeof(buffer))))
	{
		if(z == -1)
		{
			break;
		}	
		
		query->insertItem(QString::fromLocal8Bit(buffer).stripWhiteSpace());
	}
	
	query->lineEdit()->setText("");
	
	history.close();	
}

void MainWindow::save_history()
{
	char buffer[255];

	QString sql;

#ifndef WIN32
	sprintf(buffer, "%s/%s", getenv("HOME"), ".mysqlnavigator.history");  
#else
	sprintf(buffer, "%s/%s", "c:", ".mysqlnavigator.history");  
#endif

	QFile history(buffer);

	if(history.open(IO_WriteOnly) == FALSE)
		return;

	for(int z = 0; z < query->count(); z++)
		sql += query->text(z).local8Bit().simplifyWhiteSpace() + "\n";

	history.writeBlock(sql.latin1(), sql.length());

	history.close();
}

void MainWindow::clear_history()
{
	query->clear();
}

void MainWindow::enable_menu()
{
	menuBar()->setItemEnabled(ID_OPEN, FALSE);
	menuBar()->setItemEnabled(ID_NEW, TRUE);
	menuBar()->setItemEnabled(ID_QUIT, TRUE);
	menuBar()->setItemEnabled(ID_CLOSE, TRUE);
	menuBar()->setItemEnabled(ID_CLOSE_ALL, TRUE);
	menuBar()->setItemEnabled(ID_SCHEMA, TRUE);
	menuBar()->setItemEnabled(ID_USER, TRUE);
	menuBar()->setItemEnabled(ID_TABLE, TRUE);
	menuBar()->setItemEnabled(ID_FIELD, TRUE);
	menuBar()->setItemEnabled(ID_LOG, TRUE);
	menuBar()->setItemEnabled(ID_QUERY, TRUE);
	menuBar()->setItemEnabled(ID_SCRIPT, TRUE);
	menuBar()->setItemEnabled(ID_PROCESS, TRUE);
	menuBar()->setItemEnabled(ID_PASSWORD, TRUE);
	menuBar()->setItemEnabled(ID_FLUSH, TRUE);
	menuBar()->setItemEnabled(ID_XPORT, TRUE);
	menuBar()->setItemEnabled(ID_PRIVILEGE, TRUE);
	menuBar()->setItemEnabled(ID_FIND, TRUE);
	menuBar()->setItemEnabled(ID_KEY, TRUE);

	query->setEditable(TRUE);
}

void MainWindow::disable_menu()
{
	menuBar()->setItemEnabled(ID_OPEN, TRUE);
	menuBar()->setItemEnabled(ID_NEW, FALSE);
	menuBar()->setItemEnabled(ID_QUIT, FALSE);
	menuBar()->setItemEnabled(ID_CLOSE, FALSE);
	menuBar()->setItemEnabled(ID_CLOSE_ALL, FALSE);
	menuBar()->setItemEnabled(ID_SCHEMA, FALSE);
	menuBar()->setItemEnabled(ID_USER, FALSE);
	menuBar()->setItemEnabled(ID_TABLE, FALSE);
	menuBar()->setItemEnabled(ID_FIELD, FALSE);
	menuBar()->setItemEnabled(ID_LOG, FALSE);
	menuBar()->setItemEnabled(ID_QUERY, FALSE);
	menuBar()->setItemEnabled(ID_SCRIPT, FALSE);
	menuBar()->setItemEnabled(ID_PROCESS, FALSE);
	menuBar()->setItemEnabled(ID_PASSWORD, FALSE);
	menuBar()->setItemEnabled(ID_FLUSH, FALSE);
	menuBar()->setItemEnabled(ID_XPORT, FALSE);
	menuBar()->setItemEnabled(ID_PRIVILEGE, FALSE);
	menuBar()->setItemEnabled(ID_FIND, FALSE);
	menuBar()->setItemEnabled(ID_KEY, FALSE);
	
	query->setEditable(FALSE);
}
