#include "xmlparser.h"
#include "base64.h"
#include <qfile.h>
#include <stdio.h>
#include <stdlib.h>
#include <qdom.h>
#include <qstatusbar.h>
#include <qmessagebox.h>

bool XMLParser::parse_rc()
{
	char buffer[100];

#ifndef WIN32
	sprintf(buffer, "%s/.mysqlnavigator.rc", getenv("HOME"));
#else
	sprintf(buffer, "%s/.mysqlnavigator.rc", "c:");
#endif

	QFile xml(buffer);

	if(xml.exists() == FALSE)
		return FALSE;
		
	if(xml.open(IO_ReadOnly) == FALSE)
		return FALSE;
	
	QDomDocument mysql("mysql");

	if(mysql.setContent(&xml) == FALSE)
	{
		xml.close();
		return FALSE;
	}

	xml.close();

	QDomNode node;
	QDomNodeList value;
	
	value = mysql.elementsByTagName("image");
	node = value.item(0);		
		
	if(node.isElement())
	{
		option->image.flag = node.namedItem("flag").firstChild().nodeValue().toInt();
		option->image.file= node.namedItem("file").firstChild().nodeValue();
	}
	
	value = mysql.elementsByTagName("password");
	node = value.item(0);		
	
	if(node.isElement())
		option->password.flag = node.firstChild().nodeValue().toInt();
	
	value = mysql.elementsByTagName("schema");
	node = value.item(0);		
	
	if(node.isElement())
		option->schema.flag = node.firstChild().nodeValue().toInt();
	
	value = mysql.elementsByTagName("exit");
	node = value.item(0);		
		
	if(node.isElement())
		option->exit.flag = node.firstChild().nodeValue().toInt();

	value = mysql.elementsByTagName("from");
	node = value.item(0);		
		
	if(node.isElement())
		option->from = node.firstChild().nodeValue().toInt();

	value = mysql.elementsByTagName("to");
	node = value.item(0);		
		
	if(node.isElement())
		option->to = node.firstChild().nodeValue().toInt();

	value = mysql.elementsByTagName("style");
	if(value.count() != 0)	
		option->style = atoi(value.item(0).firstChild().nodeValue());
	
	value = mysql.elementsByTagName("width");
	if(value.count() != 0)	
		option->size.setWidth(atoi(value.item(0).firstChild().nodeValue()));
	
	value = mysql.elementsByTagName("height");
	if(value.count() != 0)	
		option->size.setHeight(atoi(value.item(0).firstChild().nodeValue()));

	// process
	value = mysql.elementsByTagName("process");
	node = value.item(0);		

	if(node.isElement())
	{
		QDomNode z;
		z = node.firstChild();
		option->process.flag = z.firstChild().nodeValue().toInt();
		z = z.nextSibling();
		option->process.value = z.firstChild().nodeValue().toInt();
	}

	// font
	value = mysql.elementsByTagName("save");
	node = value.item(0);		
	
	if(node.isElement())
		option->save = node.firstChild().nodeValue().toInt();

	value = mysql.elementsByTagName("font");
	node = value.item(0);		

	if(node.isElement())
	{
		QFont s;

		QDomNode z;
		z = node.firstChild();
		option->font.family = QString::fromLocal8Bit(z.firstChild().nodeValue());
		z = z.nextSibling();
		option->font.bold = z.firstChild().nodeValue().toInt();
		z = z.nextSibling();
		option->font.italic = z.firstChild().nodeValue().toInt();
		z = z.nextSibling();
		option->font.size = z.firstChild().nodeValue().toInt();
		z = z.nextSibling();
		option->font.strikeout = z.firstChild().nodeValue().toInt();
		z = z.nextSibling();
		option->font.underline = z.firstChild().nodeValue().toInt();

		if(option->font.family.isEmpty() == FALSE)
		{
			s.setFamily(option->font.family);
			s.setBold(option->font.bold);
			s.setItalic(option->font.italic);
			s.setPointSize(option->font.size);
			s.setStrikeOut(option->font.strikeout);
			s.setUnderline(option->font.underline);

			qApp->setFont(s, TRUE);
		}
	}


	// clear
	value = mysql.elementsByTagName("clear");
	node = value.item(0);		
		
	if(node.isElement())
		option->clear = atoi(value.item(0).firstChild().nodeValue());

	// log
	value = mysql.elementsByTagName("log");
	node = value.item(0);		
		
	if(node.isElement())
		option->log = atoi(value.item(0).firstChild().nodeValue());

	// server
	value = mysql.elementsByTagName("server");

	for(unsigned int s = 0; s < value.count(); s++)
	{
		struct server_data data;
		QString host;

		QDomNode node;

		node = value.item(s).firstChild();	// host node
		host = node.firstChild().nodeValue();

		node= node.nextSibling();	// user node
		data.user = node.firstChild().nodeValue();
					
		node= node.nextSibling();	// password node
		data.password = node.firstChild().nodeValue();
		if(data.password.at(0) == '$')
		{
			data.password = data.password.right(data.password.length() - 1);
			char *z = new char[data.password.length() + 1];
			FromBase64(z, (const void *)data.password.latin1(), data.password.length(), TRUE);
			data.password = z;
			delete []z;
		}
		
		node= node.nextSibling();	// database node
		data.database = node.firstChild().nodeValue();

		node= node.nextSibling();	// port node
		data.port = node.firstChild().nodeValue();
					
		node= node.nextSibling();	// socket node
		data.socket = node.firstChild().nodeValue();
	
		server_map->insert(data.user + "@" + host, data);	
	}

	/*
	switch(option->style)
	{
		case 0:
			slot_windows();
			break;
		case 1:
			slot_cde();
			break;
		case 2:
			slot_motif();
			break;
		case 3:
			slot_motif_plus();
			break;
		case 4:
			slot_platinum();
			break;
		case 5:
			slot_sgi();
			break;
		case 6:
			slot_jfc();
			break;
		case 7:
			slot_nextstep();
			break;
		default:
			slot_windows();
			break;
	}
	*/
	return TRUE;	
}

bool XMLParser::save_rc()
{
	QDomElement value;
	QDomElement s;
	QDomDocument z("mysql");

	z.appendChild(z.createElement("mysql"));	// document element

	// image
	z.documentElement().appendChild(value = z.createElement("image"));
	value.appendChild(s = z.createElement("flag"));
	s.appendChild(z.createTextNode(option->image.flag ? "1" : "0"));
	value.appendChild(s = z.createElement("file"));
	s.appendChild(z.createTextNode(option->image.file.simplifyWhiteSpace()));
	
	// schema
	z.documentElement().appendChild(value = z.createElement("schema"));
	value.appendChild(z.createTextNode(option->schema.flag ? "1" : "0"));

	// password
	z.documentElement().appendChild(value = z.createElement("password"));
	value.appendChild(z.createTextNode(option->password.flag ? "1" : "0"));

	// from
	z.documentElement().appendChild(value = z.createElement("from"));
	value.appendChild(z.createTextNode(QString::number(option->from)));	

	// to
	z.documentElement().appendChild(value = z.createElement("to"));
	value.appendChild(z.createTextNode(QString::number(option->to)));	

	// style
	z.documentElement().appendChild(value = z.createElement("style"));
	value.appendChild(z.createTextNode(QString::number(option->style)));	
	
	// size
	z.documentElement().appendChild(value = z.createElement("size"));
	value.appendChild(s = z.createElement("width"));
	s.appendChild(z.createTextNode(QString::number(option->size.width())));
	value.appendChild(s = z.createElement("height"));
	s.appendChild(z.createTextNode(QString::number(option->size.height())));

	// exit
	z.documentElement().appendChild(value = z.createElement("exit"));
	value.appendChild(z.createTextNode(option->exit.flag ? "1" : "0"));

	/*
	// toolbar
	z.documentElement().appendChild(value = z.createElement("toolbar"));
	value.appendChild(z.createTextNode(QString::number(toolbar->isVisible())));

	// statusbar
	z.documentElement().appendChild(value = z.createElement("statusbar"));
	value.appendChild(z.createTextNode(QString::number(statusbar->isVisible())));
	*/

	// process
	z.documentElement().appendChild(value = z.createElement("process"));
	value.appendChild(s = z.createElement("flag"));
	s.appendChild(z.createTextNode(QString::number(option->process.flag)));
	value.appendChild(s = z.createElement("value"));
	s.appendChild(z.createTextNode(QString::number(option->process.value)));

	// clear
	z.documentElement().appendChild(value = z.createElement("clear"));
	value.appendChild(z.createTextNode(option->clear ? "1" : "0"));

	// log
	z.documentElement().appendChild(value = z.createElement("log"));
	value.appendChild(z.createTextNode(option->log ? "1" : "0"));

	// server
	QMap<QString, struct server_data>::Iterator sql;
	for(sql = server_map->begin(); sql != server_map->end(); ++sql)
	{
		z.documentElement().appendChild(value = z.createElement("server"));
		value.appendChild(s = z.createElement("host"));
		s.appendChild(z.createTextNode(get_server(sql.key())));
		value.appendChild(s = z.createElement("user"));
		s.appendChild(z.createTextNode(sql.data().user));
		value.appendChild(s = z.createElement("password"));
		if(option->password.flag)
		{
			char *p  = new char[sql.data().password.length() * 4 + 1];
			ToBase64(p, (const void *)sql.data().password.latin1(), sql.data().password.length(), TRUE);
			s.appendChild(z.createTextNode(QString("$") + p));
			delete []p;
		}
		else
		{
			s.appendChild(z.createTextNode(""));
		}
		value.appendChild(s = z.createElement("database"));
		s.appendChild(z.createTextNode(sql.data().database));
		value.appendChild(s = z.createElement("port"));
		s.appendChild(z.createTextNode(sql.data().port));
		value.appendChild(s = z.createElement("socket"));
		s.appendChild(z.createTextNode(sql.data().socket));
	}

	// font
	z.documentElement().appendChild(value = z.createElement("save"));
	value.appendChild(z.createTextNode(option->save ? "1" : "0"));

	if(option->save)
	{
		QFont font = qApp->mainWidget()->font();

		option->font.family = font.family();
		option->font.bold = font.bold();
		option->font.italic = font.italic();
		option->font.size = font.pointSize();
		option->font.strikeout = font.strikeOut ();
		option->font.underline = font.underline();
	}

	z.documentElement().appendChild(value = z.createElement("font"));
	value.appendChild(s = z.createElement("family"));
	s.appendChild(z.createTextNode(option->font.family.local8Bit()));
	value.appendChild(s = z.createElement("bold"));
	s.appendChild(z.createTextNode(QString::number(option->font.bold)));
	value.appendChild(s = z.createElement("italic"));
	s.appendChild(z.createTextNode(QString::number(option->font.italic)));
	value.appendChild(s = z.createElement("size"));
	s.appendChild(z.createTextNode(QString::number(option->font.size)));
	value.appendChild(s = z.createElement("strikeout"));
	s.appendChild(z.createTextNode(QString::number(option->font.strikeout)));
	value.appendChild(s = z.createElement("underline"));
	s.appendChild(z.createTextNode(QString::number(option->font.underline)));
			
	char log[100];

#ifndef WIN32
	sprintf(log, "%s/.mysqlnavigator.rc", getenv("HOME"));
#else
	sprintf(log, "%s/.mysqlnavigator.rc", "c:");
#endif

	QFile xml(log);

	if(xml.open(IO_WriteOnly | IO_Truncate) == FALSE)
		return FALSE;
	
	xml.writeBlock(z.toString(), z.toString().length());

	xml.close();

	return TRUE;
}

QString XMLParser::get_server(QString sql)
{
	for(unsigned int s = 0; s < sql.length(); s++)
	{
		if(sql.at(s) == '@')
		{
			return sql.mid(s + 1);
		}
	}

	return "";
}


